@@ -38,6 +38,12 @@ def window_centre(window: tk.Tk):
     window.geometry(f"{window.winfo_width()}x{window.winfo_height()}+{round(x)}+{round(y)}")
 
 
+def resize_widget(widget: tk.Widget):
+    try:
+        widget.after(10, lambda: DevResize(widget))
+    except tk.TclError:
+        pass
+
 class DevAccumulatorButton(tk.Button):
     def __init__(self):
         super(DevAccumulatorButton, self).__init__()
@@ -343,7 +349,9 @@ class DevSubWindow(tk.Frame):
                                     min_active_fg=min_active_fg,
                                     close_fg=close_fg, max_fg=max_fg, min_fg=min_fg)
         self.titlebar.pack(fill=tk.X, side=tk.TOP)
-        DevDrag(self.titlebar, self)
+        self.bind("Configure", DevResize)
+        resize_widget(self)
+        self.update()
 
     def set_titlebar(self, titlebar):
         self.titlebar = titlebar
